==> jc-1.4.0.tar.gz: soot/jimple/parser/node/PCaseLabel.h <==
// public abstract class soot.jimple.parser.node.PCaseLabel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 4c191822f0fe0fe5 soot_jimple_parser_node_PCaseLabel

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PCaseLabel_H_
#define _JC_soot_jimple_parser_node_PCaseLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	_jc_soot_jimple_parser_node_PCaseLabel$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	_jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$refs	_jc_soot_jimple_parser_node_PCaseLabel$refs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$nonrefs	_jc_soot_jimple_parser_node_PCaseLabel$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$object	_jc_soot_jimple_parser_node_PCaseLabel$object;

typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vmethods	_jc_soot_jimple_parser_node_PCaseLabel$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vtable	_jc_soot_jimple_parser_node_PCaseLabel$vtable;
typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vtype	_jc_soot_jimple_parser_node_PCaseLabel$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PCaseLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PCaseLabel$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PCaseLabel$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PCaseLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PCaseLabel$vmethods	soot_jimple_parser_node_PCaseLabel;
};

// Vtype
struct _jc_soot_jimple_parser_node_PCaseLabel$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PCaseLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PCaseLabel$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PCaseLabel$refs {
    _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PCaseLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	soot_jimple_parser_node_PCaseLabel;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PCaseLabel$object {
	_jc_soot_jimple_parser_node_PCaseLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PCaseLabel$vtype	*vtype;
	_jc_soot_jimple_parser_node_PCaseLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PCaseLabel$vtype _jc_soot_jimple_parser_node_PCaseLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PCaseLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PCaseLabel$class_object;

#endif	/* _JC_soot_jimple_parser_node_PCaseLabel_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/PCaseLabel.h <==
// public abstract class soot.jimple.parser.node.PCaseLabel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 4c191822f0fe0fe5 soot_jimple_parser_node_PCaseLabel

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PCaseLabel_H_
#define _JC_soot_jimple_parser_node_PCaseLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	_jc_soot_jimple_parser_node_PCaseLabel$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	_jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$refs	_jc_soot_jimple_parser_node_PCaseLabel$refs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$nonrefs	_jc_soot_jimple_parser_node_PCaseLabel$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PCaseLabel$object	_jc_soot_jimple_parser_node_PCaseLabel$object;

typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vmethods	_jc_soot_jimple_parser_node_PCaseLabel$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vtable	_jc_soot_jimple_parser_node_PCaseLabel$vtable;
typedef const struct _jc_soot_jimple_parser_node_PCaseLabel$vtype	_jc_soot_jimple_parser_node_PCaseLabel$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PCaseLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PCaseLabel$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PCaseLabel$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PCaseLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PCaseLabel$vmethods	soot_jimple_parser_node_PCaseLabel;
};

// Vtype
struct _jc_soot_jimple_parser_node_PCaseLabel$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PCaseLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PCaseLabel$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PCaseLabel$refs {
    _jc_soot_jimple_parser_node_PCaseLabel$sub_refs	soot_jimple_parser_node_PCaseLabel;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PCaseLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PCaseLabel$sub_nonrefs	soot_jimple_parser_node_PCaseLabel;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PCaseLabel$object {
	_jc_soot_jimple_parser_node_PCaseLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PCaseLabel$vtype	*vtype;
	_jc_soot_jimple_parser_node_PCaseLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PCaseLabel$vtype _jc_soot_jimple_parser_node_PCaseLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PCaseLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PCaseLabel$class_object;

#endif	/* _JC_soot_jimple_parser_node_PCaseLabel_H_ */
